@@ -14,8 +14,10 @@ The most commonly used commands are:
     update_derived          update derived data based on basic and raw data
     update_view             update view data based on basic and derived data
     data_update             run download_raw, update_basic, update_derived and update_view in turn
+    check_fund_list         check fund list to get new funds and delisted funds
 '''
 
+
 class SurfingEntrance(object):
     # TODO: rename to Surfing and move parser out of __init__
     # Make this class usable in other scripts
@@ -38,6 +40,10 @@ class SurfingEntrance(object):
         print(f'yesterday: {yesterday_str}')
         return yesterday_str
 
+    def datetime_test(self):
+        import datetime
+        print(datetime.datetime.today())
+
     def init_raw(self):
         from .data.wrapper.mysql import RawDatabaseConnector
         from .data.view.raw_models import Base
@@ -80,7 +86,7 @@ class SurfingEntrance(object):
         rq_license = SurfingConfigurator().get_license_settings('rq')
         raw_data_downloader = RawDataDownloader(rq_license)
         return raw_data_downloader.download(yesterday, yesterday), raw_data_downloader.get_updated_count()
-    
+
     def update_basic(self, yesterday=None):
         if not yesterday:
             yesterday = self._get_yesterday()
@@ -89,7 +95,7 @@ class SurfingEntrance(object):
 
         basic_data_processor = BasicDataProcessor()
         return basic_data_processor.process_all(yesterday, yesterday), basic_data_processor.get_updated_count()
-    
+
     def update_derived(self, yesterday=None):
         if not yesterday:
             yesterday = self._get_yesterday()
@@ -137,7 +143,7 @@ class SurfingEntrance(object):
             failed_tasks['derived'] = derived_failed_tasks
         updated_count['derived'] = derived_updated_count
         print('Step 3. Done update derived')
-        
+
         print('Step 4. Start update view')
         view_failed_tasks = self.update_view(yesterday)
         if len(view_failed_tasks) > 0:
@@ -151,7 +157,56 @@ class SurfingEntrance(object):
         from .util.wechat_bot import WechatBot
         wechat_bot = WechatBot()
         wechat_bot.send_data_update_status(yesterday, failed_tasks, updated_count)
-    
+
+        self.check_fund_list(yesterday, wechat_bot)
+
+    def check_fund_list(self, yesterday=None, wechat_bot=None):
+        from .data.fund.raw.raw_data_helper import RawDataHelper
+        from .data.api.raw import RawDataApi
+
+        if yesterday is None:
+            yesterday = self._get_yesterday()
+        if wechat_bot is None:
+            from .util.wechat_bot import WechatBot
+            wechat_bot = WechatBot()
+        new_funds, new_delisted_funds = RawDataHelper.get_new_and_delisted_fund_list(yesterday)
+        if new_funds is not None and new_delisted_funds is not None:
+            # 获取新增基金以及新摘牌基金列表
+            agg_funds = new_funds.union(new_delisted_funds)
+            if agg_funds:
+                # 不是OF结尾的我们把它换成OF也去查一下
+                agg_funds.update({one.split('.')[0] + '.OF' for one in agg_funds if not one.endswith('.OF')})
+
+                api = RawDataApi()
+                # 在已有的fund_info里找对应基金的信息
+                wind_df = api.get_wind_fund_info(agg_funds)
+                fund_name_got = {row.wind_id: row.desc_name for row in wind_df.itertuples(index=False)}
+                # 在Choice的fund_info里找剩余还没找到的基金信息
+                em_df = api.get_em_fund_info(agg_funds.difference(set(fund_name_got.keys())))
+                fund_name_got.update({row.em_id: row.name for row in em_df.itertuples(index=False)})
+
+                # 拆回到原来的两个列表里
+                new_funds_with_name = {}
+                for fund_id in sorted(new_funds):
+                    try:
+                        new_funds_with_name[fund_id] = fund_name_got[fund_id]
+                    except KeyError:
+                        # 把结尾换成.OF再查一下
+                        new_funds_with_name[fund_id] = fund_name_got.get(fund_id.split('.')[0] + '.OF', None)
+                        if new_funds_with_name[fund_id] is not None:
+                            new_funds_with_name[fund_id] += '(场内)'
+
+                new_delisted_funds_with_name = {}
+                for fund_id in sorted(new_delisted_funds):
+                    try:
+                        new_delisted_funds_with_name[fund_id] = fund_name_got[fund_id]
+                    except KeyError:
+                        # 把结尾换成.OF再查一下
+                        new_delisted_funds_with_name[fund_id] = fund_name_got.get(fund_id.split('.')[0] + '.OF', None)
+                        if new_delisted_funds_with_name[fund_id] is not None:
+                            new_delisted_funds_with_name[fund_id] += '(场内)'
+        wechat_bot.send_new_fund_list(yesterday, new_funds_with_name, new_delisted_funds_with_name)
+
 
 if __name__ == "__main__":
     entrance = SurfingEntrance()
