@@ -1,4 +1,9 @@
 import inspect
+import enum
+
+
+INDEX_PRICE_EXTRA_TRADE_DAYS = 15
+
 
 class ReadableEnum(object):
     _code_name_cache = None
@@ -28,6 +33,25 @@ class ReadableEnum(object):
         return cls._code_name_cache[1].get(code, code)
 
 
+# 板块类型
+class SectorType(enum.Enum):
+    industry = 1
+    topic = 2
+
+
+# 指数价格数据来源类型
+class IndexPriceSource(enum.Enum):
+    default = 1
+    none = 2
+    macroeconomic = 3
+
+
+# 基金收费模式
+class CodeFeeMode(enum.Enum):
+    none = 0
+    a_type = 1  # 前端收费
+    b_type = 2  # 后端收费
+
 
 class ExchangeID(ReadableEnum):
     NOT_AVAILABLE = 0
@@ -204,7 +228,7 @@ class LongShort():
                 continue
             self._code_name_cache[0][attr[2]] = name
             self._code_name_cache[1][name] = attr
-        
+
         return self._code_name_cache[1][self._code_name_cache[0].get(code, code)]
 
 class ExchangeStatus(ReadableEnum):
