@@ -723,6 +723,20 @@ class RawDataApi:
                 )
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
+            except Exception as e:
+                print('Failed to get data <err_msg> {}'.format(e))
+                return None
+    
+    def get_em_fund_rate(self, datetime: str):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(
+                    EMFundRate
+                ).filter(
+                    EMFundRate.DATES == datetime, 
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                return df
             except Exception as e:
                 print('Failed to get data <err_msg> {}'.format(e))
                 return None
\ No newline at end of file
