@@ -389,6 +389,71 @@ class BasicDataPart1:
             traceback.print_exc()
             return False
 
+    def fund_rate(self, end_date):
+        def _count_star_history(x):
+            color_change = {
+                '红':'蓝',
+                '蓝':'白',
+                '白':'红',    
+            }
+            if x is None:
+                return None
+            if '星' in x:
+                return str(x.count('★') + x.count('☆') + 1) + color_change[x[-2]] 
+            else:
+                return str(x.count('★') + x.count('☆')) 
+
+        def _count_star_recent(x):
+            if x is None:
+                return None
+            if '星' in x:
+                return str(x.count('★') + x.count('☆') + 1) + x[-2]
+            else:
+                return str(x.count('★') + x.count('☆')) 
+        try:
+            df = RawDataApi().get_em_fund_rate(end_date)
+            df['fund_id'] = df.apply( lambda x : self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
+            no_star_columns = ['CODES','DATES','_update_time','fund_id']
+            for col in df:
+                if col in no_star_columns:
+                    continue 
+                df[col] = df[col].map(lambda x : _count_star_recent(x))  
+            df = df.drop(['CODES','_update_time'], axis=1)
+            name_dic = {
+                'DATES':'datetime',
+                'MKTCOMPRE3YRAT':'mkt_3y_comp',
+                'MORNSTAR3YRAT':'mornstar_3y',
+                'MORNSTAR5YRAT':'mornstar_5y',
+                'MERCHANTS3YRAT':'merchant_3y',
+                'TXCOMRATRAT':'tx_comp',
+                'SHSTOCKSTAR3YCOMRAT':'sh_3y_comp',
+                'SHSTOCKSTAR3YSTOCKRAT':'sh_3y_stock',
+                'SHSTOCKSTAR3YTIMERAT':'sh_3y_timeret',
+                'SHSTOCKSTAR3YSHARPERAT':'sh_3y_sharpe',
+                'SHSTOCKSTAR5YCOMRATRAT':'sh_5y_comp',
+                'SHSTOCKSTAR5YSTOCKRAT':'sh_5y_stock',
+                'SHSTOCKSTAR5YTIMERAT':'sh_5y_timeret',
+                'SHSTOCKSTAR5YSHARPRAT':'sh_5y_sharpe',
+                'JAJXCOMRAT':'jian_comp',
+                'JAJXEARNINGPOWERRAT':'jian_earn',
+                'JAJXACHIEVESTABILITYRAT':'jian_stable',
+                'JAJXANTIRISKRAT':'jian_risk',
+                'JAJXSTOCKSELECTIONRAT':'jian_stock',
+                'JAJXTIMESELECTIONRAT':'jian_timeret',
+                'JAJXBENCHMARKTRACKINGRAT':'jian_track',
+                'JAJXEXCESSEARNINGSRAT':'jian_alpha',
+                'JAJXTOTALFEERAT':'jian_fee',
+                'fund_id':'fund_id',
+            }
+            df = df.rename(columns = name_dic)
+            df = df.dropna(subset=['fund_id','datetime'], axis=0)
+            self._data_helper._upload_basic(df, FundRate.__table__.name)
+            return True
+        except Exception as e:
+            print(e)
+            traceback.print_exc()
+            return False
+            
     def trading_day_list(self, start_date, end_date, is_automatic_update=True):
         try:
             # 如果是每日自动更新，我们需要去存T+1日的数据
@@ -438,7 +503,6 @@ class BasicDataPart1:
 
     def process_all(self, start_date, end_date):
         failed_tasks = []
-
         # Depend on RQ
         # if not self.rq_fund_ret(start_date, end_date):
         #     failed_tasks.append('rq_fund_ret')
@@ -468,9 +532,10 @@ class BasicDataPart1:
         if not self.trading_day_list(start_date, end_date):
             failed_tasks.append('trading_day_list')
 
+        if not self.fund_rate(end_date):
+            failed_tasks.append('fund_rate')
         return failed_tasks
 
-
 if __name__ == '__main__':
     bdp = BasicDataPart1(BasicDataHelper())
     # start_date = '20200428'
