@@ -108,7 +108,7 @@ class BasicFundRet(BasicDataPart1):
 
         except Exception as e:
             print(e)
-            traceback.print_stack()
+            traceback.print_exc()
             failed_tasks.append('fund_score')
 
         return failed_tasks
