@@ -144,7 +144,7 @@ class StyleAnalysisProcessor(object):
             self._data_helper._upload_derived(self._factor_return.loc[start_date:end_date, :].reset_index(), StyleAnalysisFactorReturn.__table__.name)
         except Exception as e:
             print(e)
-            traceback.print_stack()
+            traceback.print_exc()
             failed_tasks.append('style_analysis_factor_return')
         return failed_tasks
 
