@@ -771,9 +771,9 @@ class EmRawDataDownloader:
         try:
             # 获取区间内所有交易日
             df = RawDataApi().get_em_tradedates(start_date, end_date)
-            if df.shape[0] == 0:
+            if df is None or df.shape[0] == 0:
                 print(f'[em_stock_estimate_fac] no trade dates, return immediately (start_date){start_date} (end_date){end_date}')
-                return
+                return False
 
             # 获取所有A股股票的ID, 功能函数-板块成分
             # http://quantapi.eastmoney.com/Cmd/Sector?from=web
@@ -781,7 +781,7 @@ class EmRawDataDownloader:
             stock_id_result = c.sector('001004', end_date)
             if stock_id_result.ErrorCode != 0:
                 print(f'failed to get stock id list: {stock_id_result.ErrorMsg}')
-                return
+                return False
 
             if predict_year == 0:
                 predict_year = datetime.datetime.strptime(end_date, '%Y%m%d').date().year + 1
@@ -794,7 +794,7 @@ class EmRawDataDownloader:
                 if not isinstance(temp_df, pd.DataFrame):
                     if temp_df.ErrorCode != 0:
                         print(f'failed to get stock daily info: {temp_df.ErrorMsg} (date){date}')
-                    return
+                    return False
                 # 日期列修改为end_date
                 temp_df.loc[:, 'DATES'] = date
                 df_list.append(temp_df)
@@ -813,70 +813,52 @@ class EmRawDataDownloader:
     def em_index_val(self, start_date: str, end_date: str):
         try:
             # 获取区间内所有交易日
-            tradedates = c.tradedates(start_date, end_date, "period=1,order=1,market=CNSESH")
-            if tradedates.ErrorCode != 0:
-                print(f'[em_index_val] failed to get trade dates: {tradedates.ErrorMsg}')
-                return
-            if len(tradedates.Data) == 0:
+            trade_day_df = RawDataApi().get_em_tradedates(start_date, end_date)
+            if trade_day_df is None or trade_day_df.shape[0] == 0:
                 print(f'[em_index_val] no trade dates, return immediately (start_date){start_date} (end_date){end_date}')
-                return
+                return False
 
             # 获取basic table中index_info信息
             index_info_df = BasicDataApi().get_index_info()
-            # 下边几个指数特殊处理
-            special_list = "399006.SZ,000300.SH,000905.SH,SPX.GI"
-            # 获取index_info中满足条件的上述几个指数之外的所有指数
-            other_indexes = index_info_df[~index_info_df.loc[:, 'em_id'].isin(special_list.split(',')) & index_info_df.loc[:, 'tag_method'].isin(['PE百分位', 'PB百分位'])]['em_id'].dropna()
-            black_list = ['H30407.CSI']
-            other_indexes = [ _ for _ in other_indexes if _ not in black_list ]
-            # extra_df = RawDataApi().get_em_index_info()
-            # extra_df = extra_df[~extra_df.em_id.isin(['H30407.CSI']+special_list.split(','))]
-            # others_list = list(set(other_indexes.to_list() + extra_df.em_id.to_list()))
+            if index_info_df is None:
+                print(f'[em_index_val] get index info failed')
+                return False
+            index_info_df = index_info_df[index_info_df.price_source == IndexPriceSource.default]
+            em_indexes = index_info_df[index_info_df.tag_method.isin(['PE百分位', 'PB百分位'])].em_id
+            # 过滤掉几个特殊指数
+            em_indexes = em_indexes[em_indexes.notna() & ~em_indexes.isin(['LIGBP1M.IR', 'HIBOR3M.IR', 'AU9999.SGE', 'AU0.SHF'])]
+            index_list = em_indexes.to_list()
+            if not index_list:
+                print(f'[em_index_val] empty index list, return immediately')
+                return False
 
-            '''
-            def transform_tradedates(x: str):
-                day, month, year = x.split('/')
-                return datetime.date(int(day), int(month), int(year)).strftime('%Y/%m/%d')
-            transformed_tradedates = list(map(transform_tradedates, tradedates.Data))
-            '''
-            df_list = []
-            for date in tradedates.Data:
-                _d = date.replace('/','-')
-                _y = int(date.split('/')[0]) + 1
-                # 一天一天地获取
-                indexes_df = c.csd(special_list,
-                                "PETTM,PBMRQ,DIVIDENDYIELD,PSTTM,PCFTTM,ROE,EPSTTM",
-                                date, date,
-                                "DelType=1,period=1,adjustflag=1,curtype=1,order=1,market=0,Ispandas=1")
-                
-                indexes_df_1 = c.css(special_list,"ESTPEG",f"TradeDate={_d},PREDICTYEAR={_y}")
-                indexes_df = indexes_df.join(pd.DataFrame(indexes_df_1.Data).T.rename(columns={0:'ESTPEG'}))
-                
-                if not isinstance(indexes_df, pd.DataFrame) and indexes_df.ErrorCode != 0:
-                    print(f'failed to get index val info: {indexes_df.ErrorMsg} (date){date}')
-                    return
-                # df_list.append(indexes_df.loc[indexes_df['DATES'].isin(transformed_tradedates), :])
-                df_list.append(indexes_df)
+            df_list: List[pd.DataFrame] = []
+            # 一天一天地获取
+            for date in trade_day_df.TRADEDATES:
+                data = c.csd(index_list,
+                           "PETTM,PBMRQ,DIVIDENDYIELD,PSTTM,PCFTTM,ROE,EPSTTM",
+                           date, date,
+                           "DelType=1,period=1,adjustflag=1,curtype=1,order=1,market=0,Ispandas=1")
+                if not isinstance(data, pd.DataFrame):
+                    if data.ErrorCode != 0:
+                        print(f'failed to get index val info: {data.ErrorMsg} (date){date}')
+                    break
 
-                # 两组指数可能获取的日期范围有一些区别，所以分开获取
-                # other_indexes_df = c.csd(others_list,
-                other_indexes_df = c.csd(other_indexes,
-                                        "PETTM,PBMRQ,DIVIDENDYIELD,PSTTM,PCFTTM,ROE,EPSTTM",
-                                        date, date,
-                                        "DelType=1,period=1,adjustflag=1,curtype=1,order=1,market=0,Ispandas=1")
-                
-                other_indexes_df_1 = c.css(other_indexes,"ESTPEG",f"TradeDate={_d},PREDICTYEAR={_y}")
-                other_indexes_df = other_indexes_df.join(pd.DataFrame(other_indexes_df_1.Data).T.rename(columns={0:'ESTPEG'}))
-                
-                if not isinstance(other_indexes_df, pd.DataFrame) and other_indexes_df.ErrorCode != 0:
-                    print(f'failed to get index val info: {other_indexes_df.ErrorMsg} (date){date}')
-                    return
-                # df_list.append(other_indexes_df.loc[other_indexes_df['DATES'].isin(transformed_tradedates), :])
-                df_list.append(other_indexes_df)
+                _y = pd.to_datetime(date).date().year + 1
+                another_data = c.css(index_list, "ESTPEG", f"TradeDate={date},PREDICTYEAR={_y},Ispandas=1")
+                if not isinstance(another_data, pd.DataFrame):
+                    if another_data.ErrorCode != 0:
+                        print(f'failed to get index val info part 2: {another_data.ErrorMsg} (date){date}')
+                    break
+                df_list.append(data.join(another_data.drop(columns='DATES'), how='outer'))
 
-            # 更新到db
-            df = pd.concat(df_list).reset_index().rename(columns=lambda x: EmIndexVal.__getattribute__(EmIndexVal, x).name)
-            self._data_helper._upload_raw(df, EmIndexVal.__table__.name)
+            if df_list:
+                if len(df_list) == 1:
+                    df = df_list[0]
+                else:
+                    df = pd.concat(df_list)
+                df = df.reset_index().rename(columns=lambda x: EmIndexVal.__getattribute__(EmIndexVal, x).name)
+                self._data_helper._upload_raw(df, EmIndexVal.__table__.name)
             return True
         except Exception as e:
             print(e)
@@ -1191,6 +1173,21 @@ class EmRawDataDownloader:
             traceback.print_exc()
             return False
 
+    def em_fund_rate(self, end_date: str):
+        try:
+            fund_list = c.sector('507013', end_date)
+            fund_list = fund_list.Codes
+            df=c.css(fund_list,"MKTCOMPRE3YRAT,MORNSTAR3YRAT,MORNSTAR5YRAT,MERCHANTS3YRAT,TXCOMRATRAT,SHSTOCKSTAR3YCOMRAT,SHSTOCKSTAR3YSTOCKRAT,SHSTOCKSTAR3YTIMERAT,SHSTOCKSTAR3YSHARPERAT,SHSTOCKSTAR5YCOMRATRAT,SHSTOCKSTAR5YSTOCKRAT,SHSTOCKSTAR5YTIMERAT,SHSTOCKSTAR5YSHARPRAT,JAJXCOMRAT,JAJXEARNINGPOWERRAT,JAJXACHIEVESTABILITYRAT,JAJXANTIRISKRAT,JAJXSTOCKSELECTIONRAT,JAJXTIMESELECTIONRAT,JAJXBENCHMARKTRACKINGRAT,JAJXEXCESSEARNINGSRAT,JAJXTOTALFEERAT",
+                f"EndDate={end_date},Ispandas=1")
+            df['DATES'] = datetime.datetime.strptime(end_date,'%Y%m%d').date()
+            df = df.reset_index()
+            self._data_helper._upload_raw(df, EMFundRate.__table__.name)
+            return True
+        except Exception as e:
+            print(e)
+            traceback.print_exc()
+            return False
+
     def download_all(self, start_date, end_date):
         failed_tasks = []
         # If em_tradedates fails, there is no trading day between start_date and end_date
@@ -1248,6 +1245,8 @@ class EmRawDataDownloader:
         if not self.em_macroeconomic_price(start_date, end_date):
             failed_tasks.append('em_macroeconomic_price')
 
+        if not self.em_fund_rate(end_date):
+            failed_tasks.append('em_fund_rate')
         # if not self.em_fund_benchmark(start_date, end_date):
         #     failed_task.append('em_fund_benchmark')
 
