@@ -306,7 +306,7 @@ class FundDailyCollectionProcessor(object):
             return True
         except Exception as e:
             print(e)
-            traceback.print_stack()
+            traceback.print_exc()
             return False
 
     def process(self):
