@@ -289,3 +289,33 @@ class Fund_size_and_hold_rate(Base):
     size = Column(DOUBLE(asdecimal=False)) # 最新规模
     personal_holds = Column(DOUBLE(asdecimal=False)) # 个人持有比例 单位百分比 
     institution_holds = Column(DOUBLE(asdecimal=False)) # 机构持有比例 单位百分比 
+
+class FundRate(Base):
+    '''基金评级'''
+
+    __tablename__ = 'fund_rate'
+
+    fund_id = Column(CHAR(10), primary_key=True)  # 基金id
+    datetime = Column(DATE, primary_key=True)  # 日期
+    mkt_3y_comp = Column(CHAR(5)) # 市场综合3年评级
+    mornstar_3y =  Column(CHAR(5)) # 晨星3年评级
+    mornstar_5y =  Column(CHAR(5)) # 晨星5年评级
+    merchant_3y = Column(CHAR(5)) # 招商3年评级
+    tx_comp = Column(CHAR(5)) # 天相投顾综合评级
+    sh_3y_comp = Column(CHAR(5)) #上海证券3年评级(综合评级)
+    sh_3y_stock = Column(CHAR(5)) #上海证券3年评级(选股能力)
+    sh_3y_timeret = Column(CHAR(5)) #上海证券3年评级(择时能力) 
+    sh_3y_sharpe = Column(CHAR(5)) #上海证券3年评级(夏普比率)
+    sh_5y_comp = Column(CHAR(5)) #上海证券5年评级(综合评级)
+    sh_5y_stock = Column(CHAR(5)) #上海证券5年评级(选股能力)
+    sh_5y_timeret = Column(CHAR(5)) #上海证券5年评级(择时能力)
+    sh_5y_sharpe = Column(CHAR(5)) #上海证券5年评级(夏普比率)
+    jian_comp = Column(CHAR(5)) #济安金信基金评级(综合评级)
+    jian_earn = Column(CHAR(5)) #济安金信基金评级(盈利能力)
+    jian_stable = Column(CHAR(5)) #济安金信基金评级(业绩稳定性)
+    jian_risk = Column(CHAR(5)) #济安金信基金评级(抗风险能力)
+    jian_stock = Column(CHAR(5)) #济安金信基金评级(选股能力)
+    jian_timeret = Column(CHAR(5)) #济安金信基金评级(择时能力)
+    jian_track = Column(CHAR(5)) #济安金信基金评级(基准跟踪能力)
+    jian_alpha = Column(CHAR(5)) #济安金信基金评级(超额收益能力) 
+    jian_fee = Column(CHAR(5)) #济安金信基金评级(整体费用)
\ No newline at end of file
