@@ -324,3 +324,19 @@ class TianData(Base):
     long_term_libility_to_asset = Column(DOUBLE(asdecimal=False))  # 长期资产负债率
     current_ratio = Column(DOUBLE(asdecimal=False))  # 流动比率
     quick_ratio = Column(DOUBLE(asdecimal=False))  # 速动比率
+
+
+class AutomaticInvestmentCollection(Base):
+    """定投收益收集"""
+
+    __tablename__ = 'automatic_investment_collection'
+
+    fund_id = Column(CHAR(20), primary_key=True)  # 基金ID
+    price_time = Column(CHAR(20), primary_key=True)  # 时间
+    y1_ret = Column(DOUBLE(asdecimal=False))  # 普通定投一年收益
+    y3_ret = Column(DOUBLE(asdecimal=False))  # 普通定投三年收益
+    y5_ret = Column(DOUBLE(asdecimal=False))  # 普通定投五年收益
+    intel_y1_ret = Column(DOUBLE(asdecimal=False))  # 智能定投一年收益
+    intel_y3_ret = Column(DOUBLE(asdecimal=False))  # 智能定投三年收益
+    intel_y5_ret = Column(DOUBLE(asdecimal=False))  # 智能定投五年收益
+
