@@ -7,6 +7,7 @@ import matplotlib.pyplot as plt
 import matplotlib.cm as cm
 import matplotlib.colors as colors
 import matplotlib.dates as mdates
+from ....util.calculator import Calculator
 from matplotlib.patches import Rectangle
 CURRENT_PLATFORM = platform.system()
 if CURRENT_PLATFORM == 'Darwin':
@@ -160,4 +161,90 @@ class HybridPainter(object):
         l = pl.legend(loc='lower left',fontsize = 17)
         s = pl.title('asset and fund market value diff % ', fontsize=20)
         plt.grid() 
-        plt.show()
\ No newline at end of file
+        plt.show()
+
+    @staticmethod
+    def plot_four_layers_mv(mv_df:pd.DataFrame):
+        mv_df = mv_df / mv_df.iloc[0]
+        mv_df.plot.line(color=['C3','C1','C2','C0'],figsize=(14,8))
+        plt.title('净值对比', fontsize=20)
+        plt.legend(loc='upper left', fontsize=15)
+        plt.grid() 
+        plt.show()
+
+    @staticmethod
+    def plot_fund_alpha(fund_nav:pd.DataFrame, 
+                        fund_info:pd.DataFrame, 
+                        index_price:pd.DataFrame,
+                        fund_position_history:dict,
+                        backtest_result:dict,
+                        dts:pd.Series,
+                        ):
+        fund_info['trade_fee'] = fund_info['purchase_fee'] + fund_info['redeem_fee']
+        fee_df = fund_info[['fund_id','trade_fee']].set_index('fund_id')
+        dts = dts[(dts >=fund_nav.index[0]) & (dts <= fund_nav.index[-1])]
+        fund_nav = fund_nav.reindex(dts)
+        index_price = index_price.reindex(dts)
+        rebalance_date = backtest_result['rebalance_date'] + [backtest_result['market_value'].index.tolist()[-1]]
+        fund_desc_name = fund_info[['fund_id','desc_name']].set_index('fund_id').to_dict()['desc_name']  
+        res = {}
+        for idx, d in enumerate(rebalance_date[:-1]):
+            for fund_id in fund_position_history[d]:
+                if fund_position_history[d][fund_id]['volume'] > 0:
+                    index_id = fund_position_history[d][fund_id]['index_id']
+                    dic_i = {
+                        'start_date':d,
+                        'fund_id': fund_id,
+                        'volume':fund_position_history[d][fund_id]['volume'],
+                        'end_date':rebalance_date[idx + 1],
+                        'index_id':index_id,
+                        'price':fund_position_history[d][fund_id]['price'],
+                    }
+                    if index_id in res:
+                        res[index_id].append(dic_i)
+                    else:
+                        res[index_id] = [dic_i]
+        res_index = []
+        for index_id in res:
+            index_df = pd.DataFrame(res[index_id])
+            _res = []
+            for idx, d in enumerate(rebalance_date[:-1]):
+                start_d = d
+                end_d = rebalance_date[idx + 1]
+                index_df_i = index_df[index_df['start_date'] == start_d]
+                fund_nav_i = fund_nav.loc[start_d:end_d,index_df_i.fund_id]
+                for fund_id in fund_nav_i:
+                    fund_i_fee = fee_df.loc[fund_id,'trade_fee']
+                    fee_discount_l = np.linspace(1,1-fund_i_fee,fund_nav_i.shape[0])
+                    fund_nav_i[fund_id] = fund_nav_i[fund_id] * fee_discount_l
+                volume_i = index_df_i[['volume','fund_id']].set_index('fund_id').T
+                _df = pd.DataFrame(fund_nav_i * volume_i.values).sum(axis=1)
+                if idx == 0:
+                    begin_value = _df.values[0]
+                _res.append(_df.diff(1).fillna(0))
+            index_ret_df = pd.concat(_res).drop_duplicates(keep='first')
+            index_ret_df.iloc[0] = begin_value
+            index_ret_df = pd.DataFrame(index_ret_df).rename(columns={0:f'{index_id} funds'})
+            df_sum = index_ret_df.cumsum().join(index_price[[index_id]]).copy()#.plot()
+            df_sum = df_sum / df_sum.iloc[0]
+            df_sum[f'{index_id}_ratio'] = df_sum[f'{index_id} funds'] / df_sum[index_id]
+            df_sum = df_sum[[f'{index_id}_ratio']].rename(columns={f'{index_id}_ratio':index_id})
+            res_index.append(df_sum.fillna(method='ffill'))
+            
+        df_plot = pd.concat(res_index, sort=True,axis=1).fillna(method='ffill')
+        if 'mmf' in df_plot:
+            df_plot=df_plot.drop('mmf',axis=1)
+        
+        res = []
+        for index_id in df_plot:
+            _index_stats = Calculator.get_stat_result_from_df(df=df_plot.reset_index(), date_column='index', value_column=index_id).__dict__
+            _index_stats['index_id'] = index_id 
+            res.append(_index_stats)
+        
+        stats = pd.DataFrame(res).set_index('index_id')[['annualized_ret','annualized_vol','mdd','sharpe','mdd_date1','mdd_date2']]
+        df_plot.plot.line(figsize=(14,8))
+        plt.title('基金所属各资产价格比',fontsize=20)
+        plt.legend(loc='upper left', fontsize=15)
+        plt.grid()
+        plt.show()
+        return stats
\ No newline at end of file
