@@ -49,6 +49,7 @@ class ReportHelper:
         self.fund_indicator = dm.dts.fund_indicator
         self.taa_params = taa_helper.params if isinstance(taa_helper, TAAHelper) else None
         self.index_pct = dm.dts.index_pct
+        self.dts = dm.dts.trading_days.datetime
         trade_list = []
         for d, trade_d in self.trade_history.items():
             trade_d = [_.__dict__ for _ in trade_d]
@@ -311,14 +312,16 @@ class ReportHelper:
         FundPainter.plot_fund_mdd_amounts(self.fund_mv, self.fund_nav, self.fund_info, self.fund_position_history.copy())
         FundPainter.plot_fund_alpha(self.fund_nav, self.fund_info, self.index_price, self.fund_position_history.copy(), w)
         FundPainter.plot_mv_on_each_asset(self.fund_nav, self.fund_info, self.index_price, self.fund_position_history.copy(), w)
-    
         #HybridPainter.plot_asset_fund_mv_diff(self.asset_mv, self.fund_mv)
         # if not self.index_fee.empty:
         #     FundPainter.plot_index_fund_fee(self.index_fee)
         # if not self.turnover_df.empty:
         #     FundPainter.plot_fund_ret_each_year(self.turnover_df, w['mdd'], w['annual_ret'] )
         #     FundPainter.plot_turnover_rate_each_year(self.turnover_df, self.turnover_rate_yearly_avg)
- 
+
+    def asset_price_ratio(self):    
+        return HybridPainter.plot_fund_alpha(self.fund_nav, self.fund_info, self.index_price, self.fund_position_history.copy(), self.get_fund_stat(), self.dts)
+        
     def plot_whole(self):
         self.backtest_fund_plot()
         self.backtest_asset_plot()
@@ -429,7 +432,7 @@ class ReportHelper:
                 rank_result.append(10000)
         indicator_1.loc[:,f'{direction}_rank'] = rank_result
         return indicator_1
-    
+     
     @staticmethod
     def fund_trade_result(_bk_class,_bk_result,m):
         _dts = m.dts.trading_days.datetime.tolist()
@@ -492,6 +495,12 @@ class ReportHelper:
         st = f'check period annual ret : {annual_ret} mdd : {mdd} total_ret {total_ret} bp'
         FundPainter.plot_recent_ret(df_plot_i,begin_date,today,st,port_id)
 
-if __name__ == "__main__":
-    f._report_helper.plot_fund_score(dm=m)
+    @staticmethod
+    def rolling_analysis(rolling_year, index_id, m, mv_df, fund_annual_ret):
+        if '沪深300' in mv_df:
+            mv_df = mv_df.drop('沪深300', axis=1)
+        mv_df = mv_df.join(m.dts.index_price[[index_id]])
+        mv_df = mv_df / mv_df.shift(1)
+        annual_ret = (mv_df.rolling(window=242*rolling_year).agg(lambda x : x.prod() - 1))/rolling_year
+        FundPainter.plot_rolling_analysis(annual_ret,fund_annual_ret,rolling_year,index_id)
     
\ No newline at end of file
