@@ -11,6 +11,9 @@ from ..data.api.basic import BasicDataApi
 from ..data.struct import TAAParam, TaaTunerParam, AssetWeight
 from ..data.api.derived import DerivedDataApi
 from ..fund.engine.asset_helper import TAAHelper, TAAStatusMode
+from ..data.wrapper.mysql import *
+from ..data.view.basic_models import *
+from ..data.view.derived_models import *
 
 @dataclasses.dataclass
 class SeriesStatUnit:
@@ -285,6 +288,84 @@ class Calculator:
         return df_result.to_dict('records') 
 
 
+    @staticmethod
+    def get_val_level(x):
+        val_dict = {
+            'PB百分位':'pb_pct',
+            'PE百分位':'pe_pct',
+            'PS百分位':'ps_pct',
+        }
+        pct = getattr(x, val_dict[x.tag_method])
+        pe = x.pe_ttm
+        if None in [pct,pe]:
+            res = None
+        if pct < 0.3 and pe < 20:
+            res = 'low'
+        elif pct > 0.7 and pe > 20:
+            res = 'high'
+        else:
+            res = 'median'
+        return res
+
+    @staticmethod
+    def get_index_level(dt:datetime.date=datetime.date(2020,7,20)):
+    
+        with BasicDatabaseConnector().managed_session() as db_session:
+            query = db_session.query(
+                    IndexInfo
+            )
+            index_info = pandas.read_sql(query.statement, query.session.bind)
+        with DerivedDatabaseConnector().managed_session() as mn_session:
+            query = mn_session.query(
+                IndexValuation
+            ).filter(
+                IndexValuation.datetime== dt,
+            )
+            index_val_df = pandas.read_sql(query.statement, query.session.bind)
+        index_val = index_val_df.set_index('index_id').join(index_info.set_index('index_id')[['tag_method']]).reset_index()
+        index_val['val_level'] = index_val.apply(lambda x : Calculator.get_val_level(x), axis=1 )
+        return index_val[['index_id','val_level']]
+
+    @staticmethod
+    def get_index_level_index(index_id:str='hs300'):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            query = db_session.query(
+                    IndexInfo
+            )
+            index_info = pandas.read_sql(query.statement, query.session.bind)
+        with DerivedDatabaseConnector().managed_session() as mn_session:
+            query = mn_session.query(
+                IndexValuation
+            ).filter(
+                IndexValuation.index_id.in_([index_id]),
+            )
+            index_val_df = pandas.read_sql(query.statement, query.session.bind)
+        index_val = index_val_df.set_index('index_id').join(index_info.set_index('index_id')[['tag_method']]).reset_index()
+        index_val['val_level'] = index_val.apply(lambda x : Calculator.get_val_level(x), axis=1 )
+        index_val = index_val[['datetime','val_level']]
+        res = []
+        last_level = 'begin'
+        dic = {}
+        for i in index_val.itertuples():
+            if i.val_level != last_level and not dic:
+                dic.update({'start_date':i.datetime})
+                dic.update({'val_level':i.val_level})
+                last_level = i.val_level
+
+            elif i.val_level != last_level and dic:
+                dic.update({'end_date':last_date})
+                last_level = i.val_level
+                res.append(dic)
+                dic = {}
+                dic.update({'start_date':i.datetime})
+                dic.update({'val_level':i.val_level})
+            last_date = i.datetime
+        if not dic:
+            dic.update({'end_date':last_date}) 
+        res.append(dic)
+        res = [i for i in res if i['val_level'] != 'median']
+        return res
+
 if __name__ == "__main__":
     # get pct with select rank
     Calculator.get_index_pct_data_df()
@@ -299,4 +380,6 @@ if __name__ == "__main__":
     Calculator.get_taa_detail(index_id='hs300',
                               index_val='pb_pct',
                               taa_param=TAAParam(),
-                              )
\ No newline at end of file
+                              )
+
+    Calculator.get_index_level_index(index_id='hs300')
\ No newline at end of file
